==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/LinearGraphRangeDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { LinearGraphRangeDescription } from "./LinearGraphRangeDescription";
/**
 * @hidden
 */
var LinearGraphRangeDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(LinearGraphRangeDescriptionMetadata, _super);
    function LinearGraphRangeDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    LinearGraphRangeDescriptionMetadata.b = function (a) {
        if (LinearGraphRangeDescriptionMetadata.a == null) {
            LinearGraphRangeDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            LinearGraphRangeDescriptionMetadata.c(LinearGraphRangeDescriptionMetadata.a);
        }
        if (a.j(LinearGraphRangeDescriptionMetadata.a)) {
            return;
        }
        a.y(LinearGraphRangeDescriptionMetadata.a);
    };
    LinearGraphRangeDescriptionMetadata.c = function (a) {
        a.item("Name", "String");
        a.item("Brush", "Brush");
        a.item("Outline", "Brush");
        a.item("StartValue", "Number:double");
        a.item("EndValue", "Number:double");
        a.item("InnerStartExtent", "Number:double");
        a.item("InnerEndExtent", "Number:double");
        a.item("OuterStartExtent", "Number:double");
        a.item("OuterEndExtent", "Number:double");
        a.item("StrokeThickness", "Number:double");
    };
    LinearGraphRangeDescriptionMetadata.d = function (a) {
        LinearGraphRangeDescriptionMetadata.b(a);
        a.aa("LinearGraphRange", function () { return new LinearGraphRangeDescription(); });
        a.z("LinearGraphRange", LinearGraphRangeDescriptionMetadata.a);
    };
    LinearGraphRangeDescriptionMetadata.$t = markType(LinearGraphRangeDescriptionMetadata, 'LinearGraphRangeDescriptionMetadata');
    LinearGraphRangeDescriptionMetadata.a = null;
    return LinearGraphRangeDescriptionMetadata;
}(Base));
export { LinearGraphRangeDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/LinearGraphRangeDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { LinearGraphRangeDescription } from "./LinearGraphRangeDescription";
/**
 * @hidden
 */
var LinearGraphRangeDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(LinearGraphRangeDescriptionMetadata, _super);
    function LinearGraphRangeDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    LinearGraphRangeDescriptionMetadata.b = function (a) {
        if (LinearGraphRangeDescriptionMetadata.a == null) {
            LinearGraphRangeDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            LinearGraphRangeDescriptionMetadata.c(LinearGraphRangeDescriptionMetadata.a);
        }
        if (a.k(LinearGraphRangeDescriptionMetadata.a)) {
            return;
        }
        a.aa(LinearGraphRangeDescriptionMetadata.a);
    };
    LinearGraphRangeDescriptionMetadata.c = function (a) {
        a.item("Name", "String");
        a.item("Brush", "Brush");
        a.item("Outline", "Brush");
        a.item("StartValue", "Number:double");
        a.item("EndValue", "Number:double");
        a.item("InnerStartExtent", "Number:double");
        a.item("InnerEndExtent", "Number:double");
        a.item("OuterStartExtent", "Number:double");
        a.item("OuterEndExtent", "Number:double");
        a.item("StrokeThickness", "Number:double");
    };
    LinearGraphRangeDescriptionMetadata.d = function (a) {
        LinearGraphRangeDescriptionMetadata.b(a);
        a.ac("LinearGraphRange", function () { return new LinearGraphRangeDescription(); });
        a.ab("LinearGraphRange", LinearGraphRangeDescriptionMetadata.a);
    };
    LinearGraphRangeDescriptionMetadata.$t = markType(LinearGraphRangeDescriptionMetadata, 'LinearGraphRangeDescriptionMetadata');
    LinearGraphRangeDescriptionMetadata.a = null;
    return LinearGraphRangeDescriptionMetadata;
}(Base));
export { LinearGraphRangeDescriptionMetadata };
